@@ -71,6 +71,40 @@ def test_version_compare():
     assert res
     res = utils.version_compare("2.9.10.4", None, "2.9.10.1")
     assert not res
+    res = utils.version_compare("2.9.10.4", None, "2.9.10")
+    assert not res
+    res = utils.version_compare("2.9.10.3", "0", "2.9.10.4")
+    assert res
+    res = utils.version_compare("2.9.10.4", "0", "2.9.10.5")
+    assert res
+    res = utils.version_compare("2.9.10.4", "0", "2.9.10.1")
+    assert not res
+    res = utils.version_compare("2.9.10.4", "0", "2.9.10")
+    assert not res
+    res = utils.version_compare("5.2.0.RELEASE", "5.2.0", "5.2.4")
+    assert res
+    res = utils.version_compare("5.2.1.FINAL", "5.2.0", "5.2.4")
+    assert res
+    res = utils.version_compare("5.2.5.FINAL", "5.2.0", "5.2.4")
+    assert not res
+    res = utils.version_compare("5.2.0.RELEASE", "5.2.0-alpha1", "5.2.4")
+    assert res
+    res = utils.version_compare("5.2.1.FINAL", "5.2.0-beta.1", "5.2.4")
+    assert res
+    res = utils.version_compare("5.2.5.FINAL", "5.2.0", "5.2.4")
+    assert not res
+    res = utils.version_compare("2.0.27.Final", None, "2.1.0")
+    assert res
+    res = utils.version_compare("2.0.27.Final", None, "2.0.29")
+    assert res
+    res = utils.version_compare("2.0.27.Final", None, None, None, "2.1.0")
+    assert res
+    res = utils.version_compare("2.0.27.Final", None, None, None, "2.0.29")
+    assert res
+    res = utils.version_compare("2.0.27.Final", "*", "*", None, "2.1.1")
+    assert res
+    res = utils.version_compare("2.0.27.Final", "*", "*", None, "2.0.29")
+    assert res
 
 
 def test_version_parts_compare():
